@@ -12,6 +12,7 @@ def execute_request(
     method: str,
     path: str,
     body: Union[Any, None] = None,
+    params: Union[Any, None] = None,
     file: Union[str, None] = None,
 ) -> Any:
   verified_credentials = verify_credentials(credentials)
@@ -30,6 +31,7 @@ def execute_request(
       method=method,
       url=f"{verified_credentials.endpoint}{path}",
       json=body,
+      params=params,
       headers={"Authorization": f"Bearer {verified_credentials.token}"},
   )
 
