@@ -100,8 +100,7 @@ class UploadCsvResponse(TypedDict):
 
 
 class UploadDatasetResponse(NamedTuple):
-  id: str
-  metaData: Optional[Dataset]
+  dataset: Optional[Dataset]
   logs: List[Logs]
 
 
