@@ -1,21 +1,20 @@
 from tim.core.credentials import Credentials
 from tim.core.api import execute_request
-from tim.types import SortDirection
 from .types import WorkspaceListPayload, Workspace
 from typing import List, Union
 
 
 def get_workspaces(
     credentials: Credentials,
-    offset: Union[int, None] = None,
-    limit: Union[int, None] = None,
+    offset: int,
+    limit: int,
     userGroupId: Union[str, None] = None,
-    sort: Union[SortDirection, None] = None
+    sort: Union[str, None] = None
 ) -> List[Workspace]:
-  payload = WorkspaceListPayload()
-  if offset: payload['offset'] = offset
-  if limit: payload['limit'] = limit
+  payload = WorkspaceListPayload(offset=offset, limit=limit)
   if userGroupId: payload['userGroupId'] = userGroupId
   if sort: payload['sort'] = sort
 
-  return execute_request(credentials=credentials, method='get', path='/workspaces', body=payload)
+  return execute_request(
+      credentials=credentials, method='get', path=f'/workspaces', params=payload
+  )
