@@ -43,7 +43,7 @@ class Tim:
         Returns
         -------
         id : str
-        metadata : Dict | None
+        dataset : Dict | None
         	Dict when successful; None when unsuccessful
         logs : list of Dict
         """
@@ -58,7 +58,7 @@ class Tim:
 
     logs = get_dataset_logs(self.__credentials, id)
 
-    return UploadDatasetResponse(id, metadata, logs)
+    return UploadDatasetResponse(metadata, logs)
 
   def create_forecast(self, dataset_id: str, job_configuration: CreateForecastConfiguration) -> str:
     """Create a forecast job in the workspace the dataset is connected to (the default workspace)
@@ -352,7 +352,7 @@ class Tim:
       userGroupId: Union[str, None] = None,
       sort: Union[str, None] = None
   ) -> List[Workspace]:
-    """Get a list of Workspaces
+    """Get a list of workspaces
 
     Parameters
     ----------
@@ -375,7 +375,7 @@ class Tim:
       workspaceId: Union[str, None] = None,
       sort: Union[str, None] = None
   ) -> List[Dataset]:
-    """Get a list  Datasets
+    """Get a list of datasets
 
     Parameters
     ----------
@@ -397,7 +397,7 @@ class Tim:
       offset: int = 0,
       limit: int = 10000,
   ) -> List[DatasetListVersion]:
-    """Get a list of (all) versions of a Dataset
+    """Get a list of the versions of a dataset
 
     Parameters
     ----------
